Enum TlsError
#[non_exhaustive]pub enum TlsError {
Native(Box<Error>),
Rustls(Box<Error>),
InvalidDnsName,
}Available on crate feature
ws only.Expand description
TLS errors.
Note that even if you enable only the rustls-based TLS support, the error at runtime could still
be Native, as another crate in the dependency graph may enable native TLS support.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Native(Box<Error>)
Available on crate feature
native-tls only.Native TLS error.
Rustls(Box<Error>)
Available on crate feature
__rustls-tls only.Rustls error.
InvalidDnsName
Available on crate feature
__rustls-tls only.DNS name resolution error.